@@ -49,7 +49,6 @@
 
 package com.openexchange.admin.reseller.storage.mysqlStorage;
 
-import static com.openexchange.tools.file.external.QuotaFileStorages.hasUserColumn;
 import static com.openexchange.tools.sql.DBUtils.getIN;
 import java.io.UnsupportedEncodingException;
 import java.security.NoSuchAlgorithmException;
@@ -740,6 +739,62 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         }
     }
 
+    @Override
+    public boolean ownsContextOrIsPidOfOwner(final Context ctx, final int admid) throws StorageException {
+        Connection oxcon = null;
+        PreparedStatement prep = null;
+        ResultSet rs = null;
+        try {
+            oxcon = cache.getConnectionForConfigDB();
+            if (ctx == null) {
+                prep = oxcon.prepareStatement("SELECT cid FROM context2subadmin WHERE sid=?");
+                prep.setInt(1, admid);
+                rs = prep.executeQuery();
+                if (!rs.next()) {
+                    return false;
+                }
+                return true;
+            } else {
+                prep = oxcon.prepareStatement("SELECT sid FROM context2subadmin WHERE cid=?");
+                prep.setInt(1, ctx.getId());
+                rs = prep.executeQuery();
+                if (!rs.next()) {
+                    return false;
+                }
+                final int ownedSid = rs.getInt("sid");
+
+                if (ownedSid == admid) {
+                    return true;
+                } else {
+                    rs.close();
+                    prep.close();
+                    prep = oxcon.prepareStatement("SELECT sid FROM subadmin WHERE pid=? AND sid=?");
+                    prep.setInt(1, admid);
+                    prep.setInt(2, ownedSid);
+                    rs = prep.executeQuery();
+                    if (!rs.next()) {
+                        return false;
+                    }
+                    return true;
+                }
+            }
+        } catch (final DataTruncation dt) {
+            log.error(AdminCache.DATA_TRUNCATION_ERROR_MSG, dt);
+            throw AdminCache.parseDataTruncation(dt);
+        } catch (final RuntimeException e) {
+            log.error("", e);
+            throw e;
+        } catch (final PoolException e) {
+            log.error("", e);
+            throw new StorageException(e.getMessage());
+        } catch (final SQLException e) {
+            log.error("", e);
+            throw new StorageException(e.getMessage());
+        } finally {
+            cache.closeConfigDBSqlStuff(oxcon, prep, rs);
+        }
+    }
+
     @Override
     public boolean checkOwnsContextAndSetSid(final Context ctx, final Credentials creds) throws StorageException {
         Connection oxcon = null;
@@ -887,13 +942,9 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
             long qused = 0;
             while (rs.next()) {
                 cid = rs.getInt("cid");
-
-                boolean hasUserColumn = hasUserColumn(con, cid);
-
                 oxcon = cache.getConnectionForContext(cid);
-                prep2 = oxcon.prepareStatement(hasUserColumn ? "SELECT filestore_usage.used FROM filestore_usage WHERE filestore_usage.cid = ? AND filestore_usage.user = 0" : "SELECT filestore_usage.used FROM filestore_usage WHERE filestore_usage.cid = ?");
+                prep2 = oxcon.prepareStatement("SELECT filestore_usage.used FROM filestore_usage WHERE filestore_usage.cid = ? AND filestore_usage.user = 0");
                 prep2.setInt(1, cid);
-
                 rs2 = prep2.executeQuery();
                 if (rs2.next()) {
                     qused += rs2.getLong(1);
@@ -904,7 +955,8 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
                 // set to null to prevent double pushback in finally
                 oxcon = null;
             }
-            if ((qused /= Math.pow(2, 20)) >= maxvalue) {
+            qused = qused >> 20;
+            if (qused >= maxvalue) {
                 throw new OXResellerException(Code.MAXIMUM_OVERALL_CONTEXT_QUOTA, String.valueOf(maxvalue));
             }
         } catch (final SQLException e) {
@@ -913,9 +965,6 @@ public final class OXResellerMySQLStorage extends OXResellerSQLStorage {
         } catch (final PoolException e) {
             log.error("", e);
             throw e;
-        } catch (final OXException e) {
-            log.error("", e);
-            throw new StorageException(e);
         } finally {
             cache.closeContextSqlStuff(oxcon, cid, true);
             cache.closeConfigDBSqlStuff(null, prep, rs);
